<?php

namespace Cadoles\CoreBundle\Controller;

use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Form\FormError;

use Cadoles\CoreBundle\Entity\Config;
use Cadoles\CoreBundle\Form\ConfigType;
use Cadoles\CoreBundle\Form\DatauserType;

class ConfigController extends Controller
{
    public function homeAction(Request $request)
    {
      	return $this->render('CadolesCoreBundle:Core:config.html.twig',[
            'useheader'     => true,
            'usemenu'       => false,
            'usesidebar'    => true,
        ]);
    }

    public function listAction()
    {
        $em = $this->getDoctrine()->getManager();

        $configs = $em->createQueryBuilder()
                      ->select('b')
                      ->from('CadolesCoreBundle:Config',  'b')
                      ->where('b.visible = :visible')
                      ->setParameter('visible', 1)
                      ->addOrderBy('b.order')
                      ->getQuery()
                      ->getResult();

        return $this->render('CadolesCoreBundle:Config:list.html.twig', [
            'useheader'     => true,
            'usemenu'       => false,
            'usesidebar'    => true,
            'configs'       => $configs
        ]);
    }

    public function updateAction($id,Request $request)
    {
        // Récupération de l'enregistrement courant
        $config=$this->getConfig($id);

        // Vérifier que cet enregistrement est modifiable
        $type=$config->getType();
        $required=$config->getRequired();
        $visible=$config->getVisible();
        $changeable=$config->getChangeable();
        if(!$visible||!$changeable) {
            return $this->redirectToRoute('cadoles_core_config_commun');
        }

        // Création du formulaire
        $form = $this->createForm(ConfigType::class,$config,array("key" => $id, "type" => $type, "required" => $required));

        // Récupération des data du formulaire
        $form->handleRequest($request);

        // Sur erreur
        $this->getErrorForm($form,$request,$config);

        // Sur validation
        if ($form->get('submit')->isClicked() && $form->isValid()) {
            $em = $this->getDoctrine()->getManager();
            $config = $form->getData();
            $em->persist($config);
            $em->flush();

            // Sur type boolean
            if($type=="boolean") {
                $qb = $em->createQueryBuilder();
                $q = $qb->update('CadolesCoreBundle:Config', 'c')
                    ->set('c.visible', ':visible')
                    ->where('c.grouped = :key')
                    ->setParameter('visible', $config->getValue())
                    ->setParameter('key', $id)
                    ->getQuery();
                $q->execute();                
            }
            return $this->redirectToRoute('cadoles_core_config_commun');
        }

        // Affichage du formulaire
        return $this->render('CadolesCoreBundle:Config:update.html.twig', [
            'useheader'     => true,
            'usemenu'       => false,
            'usesidebar'    => true,
            'config'        => $config,
            'type'          => $type,
            'form'          => $form->createView()
        ]);
    }

    public function deleteAction($id,Request $request)
    {
        // Récupération de l'enregistrement courant
        $config=$this->getConfig($id);
        if(!$config->getRequired()) {
            $config->setValue("");
            $em = $this->getDoctrine()->getManager();
            $em->persist($config);
            $em->flush();            
        }
        return $this->redirectToRoute('cadoles_core_config_commun',['usesidebar'=>true]);
    }

    public function logoAction()
    {
        return $this->render('CadolesCoreBundle:Config:logo.html.twig',[
            'useheader'     => false,
            'usemenu'       => false,
            'usesidebar'    => false,
        ]);
    }

    public function headerAction()
    {
        return $this->render('CadolesCoreBundle:Config:header.html.twig',[
            'useheader'     => false,
            'usemenu'       => false,
            'usesidebar'    => false,
        ]);
    }

    protected function getConfig($id)
    {
        $em = $this->getDoctrine()->getManager();
        $config = $em->getRepository('CadolesCoreBundle:Config')->find($id);

        if (!$config) {
            throw $this->createNotFoundException('Unable to find config.');
        }

        return $config;
    }

    public function permmodoAction()
    {
        $em = $this->getDoctrine()->getManager();

        $sidebars=$this->get('session')->get('sidebar');
        
        $perms=[];
        foreach($sidebars as $sidebar) {
            foreach($sidebar["childs"] as $child) {
                $permmod=$em->getRepository("CadolesCoreBundle:PermModo")->findOneBy(["route"=>$child["path"]]);
                if($permmod) {
                    array_push($perms,['id' => $permmod->getId(), 'label'=>$sidebar['label'].' >> '.$child['label'],'visible'=>$permmod->getVisible()]);
                }
            }
        }

        return $this->render('CadolesCoreBundle:Config:permmodo.html.twig', [
            'useheader'     => true,
            'usemenu'       => false,
            'usesidebar'    => true,
            'permmodos'     => $perms
        ]);
    }

    public function permmodoupdateAction(Request $request)
    {
        // S'assurer que c'est un appel ajax
        if (!$request->isXmlHttpRequest()) return new JsonResponse(array('message' => 'Interdit'), 400);

        $output=array();
        $id             = $request->request->get('id');

        $em = $this->getDoctrine()->getManager();
        $permmodo = $this->getDoctrine()->getRepository("CadolesCoreBundle:PermModo")->find($id);
        if (!$permmodo) throw $this->createNotFoundException('Unable to find entity.');

        $permmodo->setVisible(!$permmodo->getVisible());
        $em->persist($permmodo);
        $em->flush();        

        $response = new Response(json_encode($output));    
        $response->headers->set('Content-Type', 'application/json');        
        return $response; 
    }
        
    public function datauserAction(Request $request)
    {      
        $em = $this->getDoctrine()->getManager();	
        $session=$this->get('session');
        $config=$em->getRepository('CadolesCoreBundle:Config')->find("datauser");
        $fields=$config->getValue();

        if($fields=="") {
            // Valeur par défaut 0=caché / 1=falcultatif / 2=obligatoire
            $fields["firstname"]["perm"]=1;
            $fields["firstname"]["label"]="Prénom";

            $fields["visible"]["perm"]=2;
            $fields["visible"]["label"]="Visible";

            $fields["authlevel"]["perm"]=2;
            $fields["authlevel"]["label"]="Niveau d'authentification";

            $fields["belongingpopulation"]["perm"]=2;
            $fields["belongingpopulation"]["label"]="Population d'appartenance";

            $fields["job"]["perm"]=1;
            $fields["job"]["label"]="Métier";

            $fields["position"]["perm"]=1;
            $fields["position"]["label"]="Fonction";

            $fields["niveau02"]["perm"]=1;
            $fields["niveau02"]["label"]="Niveau 02";

            $fields["usualname"]["perm"]=1;
            $fields["usualname"]["label"]="Nom d'Usage";

            $fields["gender"]["perm"]=1;
            $fields["gender"]["label"]="Sexe";

            $fields["givensname"]["perm"]=1;
            $fields["givensname"]["label"]="Autre Prénom";

            $fields["telephonenumber"]["perm"]=1;
            $fields["telephonenumber"]["label"]="Téléphone";

            $fields["postaladress"]["perm"]=1;
            $fields["postaladress"]["label"]="Adresse";

            $fields["birthdate"]["perm"]=1;
            $fields["birthdate"]["label"]="Date de Naissance";

            $fields["birthcountry"]["perm"]=1;
            $fields["birthcountry"]["label"]="Pays de Naissance";

            $fields["birthplace"]["perm"]=1;
            $fields["birthplace"]["label"]="Ville de Naissance";
        }
        else {
            $fields=json_decode($fields, true);
        }

        if($session->get('viewniveau02')&&!array_key_exists("niveau02",$fields))
            $fields["niveau02"]["perm"]=1;
        elseif(!$session->get('viewniveau02'))
            unset($fields["niveau02"]);

        if(array_key_exists("niveau02",$fields))
            $fields["niveau02"]["label"]=$session->get('labelniveau02');
        

        
        $form = $this->createForm(DatauserType::class,$config,array("mode"=>"datauser","fields" => $fields));

        // Récupération des data du formulaire
        $form->handleRequest($request);
        
        if ($form->get('submit')->isClicked() && $form->isValid()) {
          
            foreach($fields as $key => $value) {
                $perm = $form->get($key)->getData();
                $fields[$key]["perm"]=$perm;
            }
            
            $json=json_encode($fields);
            $config->setValue($json);
            $em->persist($config);
            $em->flush();     
        }


        return $this->render('CadolesCoreBundle:Config:datauser.html.twig',[
            'useheader'     => true,
            'usemenu'       => false,
            'usesidebar'    => true,
            'form'          => $form->createView(),
            'mode'          => "datauser"
        ]);
    }

    public function datausersAction(Request $request)
    {      
        $em = $this->getDoctrine()->getManager();	
        $session=$this->get('session');
        $config=$em->getRepository('CadolesCoreBundle:Config')->find("datausers");
        $fields=$config->getValue();

        if($fields=="") {
            // Valeur par défaut 0=caché / 3=visible
            $fields["avatar"]["perm"]=1;
            $fields["avatar"]["label"]="Avatar";

            $fields["login"]["perm"]=1;
            $fields["login"]["label"]="Login";

            $fields["lastname"]["perm"]=1;
            $fields["lastname"]["label"]="Nom";

            $fields["firstname"]["perm"]=1;
            $fields["firstname"]["label"]="Prenom";

            $fields["email"]["perm"]=1;
            $fields["email"]["label"]="Email";

            $fields["niveau01"]["perm"]=1;
            $fields["niveau01"]["label"]="Niveau 01";

            $fields["niveau02"]["perm"]=1;
            $fields["niveau02"]["label"]="Niveau 02";

            $fields["group"]["perm"]=1;
            $fields["group"]["label"]="Groupes";

            $fields["role"]["perm"]=1;
            $fields["role"]["label"]="Rôles";
        }
        else {
            $fields=json_decode($fields, true);
        }

        $fields["niveau01"]["label"]=$session->get('labelniveau01');
        if($session->get('viewniveau02')&&!array_key_exists("niveau02",$fields))
            $fields["niveau02"]["perm"]=1;
        elseif(!$session->get('viewniveau02'))
            unset($fields["niveau02"]);

        if(array_key_exists("niveau02",$fields))
            $fields["niveau02"]["label"]=$session->get('labelniveau02');
        

        
        $form = $this->createForm(DatauserType::class,$config,array("mode"=>"datausers","fields" => $fields));

        // Récupération des data du formulaire
        $form->handleRequest($request);
        
        if ($form->get('submit')->isClicked()) {
            $onevisible=false;
            foreach($fields as $key => $value) {
                $perm = $form->get($key)->getData();
                $fields[$key]["perm"]=$perm;
                if($perm==1) $onevisible=true;
            }
            
            if(!$onevisible)
                $form->addError(new FormError('Au moins une colonne doit être visible'));

            if ($form->get('submit')->isClicked() && !$form->isValid()) {
                $this->get('session')->getFlashBag()->clear();
                $validator = $this->get('validator');
                $errors = $validator->validate($config);
                foreach( $errors as $error ) {
                    $request->getSession()->getFlashBag()->add("error", $error->getMessage());
                }
    
                $errors = $form->getErrors();
                foreach( $errors as $error ) {
                    $request->getSession()->getFlashBag()->add("error", $error->getMessage());
                }
            }                
        }

        if ($form->get('submit')->isClicked() && $form->isValid()) {
            $json=json_encode($fields);
            $config->setValue($json);
            $em->persist($config);
            $em->flush();     
        }


        return $this->render('CadolesCoreBundle:Config:datauser.html.twig',[
            'useheader'     => true,
            'usemenu'       => false,
            'usesidebar'    => true,
            'form'          => $form->createView(),
            'mode'          => "datausers"
        ]);
    }

    protected function getErrorForm($form,$request,$data) {
        if ($form->get('submit')->isClicked() && !$form->isValid()) {
            $this->get('session')->getFlashBag()->clear();
            $validator = $this->get('validator');
            $errors = $validator->validate($data);
            foreach( $errors as $error ) {
                $request->getSession()->getFlashBag()->add("error", $error->getMessage());
            }

            $errors = $form->getErrors();
            foreach( $errors as $error ) {
                $request->getSession()->getFlashBag()->add("error", $error->getMessage());
            }
        }
    }
}
