<?php

namespace Cadoles\CoreBundle\Controller;

use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Session\Session;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Filesystem\Filesystem;

use Cadoles\CoreBundle\Entity\Scrum;
use Cadoles\CoreBundle\Form\ScrumType;

class ScrumController extends Controller
{
    private $labelentity="CadolesCoreBundle:Scrum";

    public function listAction(Request $request) {
        $em = $this->getDoctrine()->getManager();
        $entitys = $em->getRepository($this->labelentity)->findAll();

        return $this->render($this->labelentity.':list.html.twig', [
            'useheader'         => true,
            'usemenu'           => false,
            'usesidebar'        => true,   
            'maxwidth'          => false,           
            'entitys'           => $entitys
        ]);
    }

    public function viewAction($id, Request $request, $access="user")
    {
        $em = $this->getDoctrine()->getManager();
        $entity = $em->getRepository($this->labelentity)->find($id);
        if (!$entity) throw $this->createNotFoundException('Unable to find entity.');

        $this->perm($entity);

        $form = $this->createForm(ScrumType::class,$entity, ["mode" => "view", "access" => $access]);
        return $this->render($this->labelentity.':view.html.twig',[
            'useheader'     => true,
            'usemenu'       => false,
            'usesidebar'    => ($access=="config"),   
            'maxwidth'      => false,           
            'entity'        => $entity,
            'form'          => $form->createView(),
            'access'        => $access,
        ]);
    }

    public function submitAction(Request $request, $access="user") {
        $entity = new Scrum();

        $form = $this->createForm(ScrumType::class, $entity, ["mode" => "submit", "access" => $access]);
        $form->handleRequest($request);

        if ($form->isValid()) {
            $em = $this->getDoctrine()->getManager();
            if($access=="user") $entity->setUser($this->getUser());

            $em->persist($entity);
            $em->flush();

            return $this->redirect($this->generateUrl('cadoles_core_'.$access.'_scrum_view',["id"=>$entity->getId()]));          
        }

        return $this->render($this->labelentity.':edit.html.twig', [
            'useheader'         => true,
            'usemenu'           => false,
            'usesidebar'        => ($access=="config"),   
            'maxwidth'          => ($access=="user"),           
            'entity'            => $entity,
            'mode'              => "submit",
            'form'              => $form->createView(),
            'access'            => $access,
        ]);
    }

    public function updateAction($id, Request $request, $access="user") {
        $em = $this->getDoctrine()->getManager();
        $entity = $em->getRepository($this->labelentity)->find($id);
        if (!$entity) throw $this->createNotFoundException('Unable to find entity.');

        if($entity->getUser()!=$this->getUser()&&$this->getUser()->getRole()!="ROLE_ADMIN") 
        throw $this->createNotFoundException('Permission denied');

        $form = $this->createForm(ScrumType::class, $entity, ["mode" => "update", "access" => $access]);
        $form->handleRequest($request);

        if ($form->isValid()) {
            $em->persist($entity);
            $em->flush();

            return $this->redirect($this->generateUrl('cadoles_core_'.$access.'_scrum_view',["id"=>$entity->getId()]));          
        }

        return $this->render($this->labelentity.':edit.html.twig', [
            'useheader'         => true,
            'usemenu'           => false,
            'usesidebar'        => ($access=="config"),   
            'maxwidth'          => ($access=="user"),           
            'entity'            => $entity,
            'mode'              => "update",
            'form'              => $form->createView(),
            'access'            => $access,
        ]);
    }

    public function deleteAction($id, Request $request, $access="user") {
        $em = $this->getDoctrine()->getManager();
        $entity = $em->getRepository($this->labelentity)->find($id);
        if (!$entity) throw $this->createNotFoundException('Unable to find entity.');

        if($entity->getUser()!=$this->getUser()&&$this->getUser()->getRole()!="ROLE_ADMIN") 
        throw $this->createNotFoundException('Permission denied');

        $em->remove($entity);
        $em->flush();

        if($access=="user")
            return $this->redirect($this->generateUrl('cadoles_core_home'));          
        else
            return $this->redirect($this->generateUrl('cadoles_core_config_scrum'));          
    }    

    public function uploadAction(Request $request, $access="user") {
        // Fichier temporaire uploadé
        $tmpfile    = $request->files->get('upload');
        $extention  = $tmpfile->getClientOriginalExtension();

        // Répertoire de Destination
        $fs         = new Filesystem();
        $rootdir    = $this->get('kernel')->getRootDir()."/../web";
        $fs->mkdir($rootdir."/uploads/ckeditor");
        
        // Fichier cible
        $targetName = uniqid().".".$extention;
        $targetFile = $rootdir."/uploads/ckeditor/".$targetName;
        $targetUrl  = "/".$this->getParameter('alias')."/uploads/ckeditor/".$targetName;
        $message    = "";

        move_uploaded_file($tmpfile,$targetFile);
        
        $output["uploaded"]=1;
        $output["fileName"]=$targetName;
        $output["url"]=$targetUrl;

        return new Response(json_encode($output));
    }
    
    private function perm($entity) {
        $perm=false;

        if($entity->getUser()==$this->getUser()) $perm=true;
        if($this->getUser()->getRole()=="ROLE_ADMIN") $perm=true;

        // Récupération des groupes de l'utilisateur
        if($this->getParameter("masteridentity")=="ninegate")
            $groups=$this->get('session')->get("groups");
        else
            $groups=$this->getUser()->getGroups();

        // Ses groupes ont-ils la permission 
        foreach($groups as $group) {
            if($entity->getGroups()->contains($group)) $perm=true;
        }

        // Son compte a-til la permission
        if($entity->getUsers()->contains($this->getUser())) $perm=true;

        // Erreur si non permis
        if(!$perm) throw $this->createNotFoundException('Permission denied');
    }
}
